<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.process_decideperform_add" icon="el-icon-plus" type="primary" @click="addOrUpdateHandle()">新增</el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
                :data="dataList"
                border
                v-loading="dataListLoading">

                  <el-table-column
                    fixed
                    prop="processAjApprovalId"
                    header-align="center"
                    align="center"
                    label="立案审批表id">
                  </el-table-column>
                <el-table-column
              prop="administrativeid"
              header-align="center"
              align="center"
              label="行政处罚决定书文号">
      </el-table-column>
                <el-table-column
              prop="documentNum"
              header-align="center"
              align="center"
              label="序列号">
      </el-table-column>
          <el-table-column
            prop="performDate"
            header-align="center"
            align="center"
            label="履行日期">
          </el-table-column>
          <el-table-column
            prop="performNotice"
            header-align="center"
            align="center"
            label="履行文书">
          </el-table-column>
          <el-table-column
            prop="performNoticeNum"
            header-align="center"
            align="center"
            label="履行文书编号">
          </el-table-column>
            <el-table-column
              prop="handleOrg"
              header-align="center"
              align="center"
              label="处置单位">
            </el-table-column>
                      <el-table-column
                    prop="handleContent"
                    header-align="center"
                    align="center"
                    label="处置内容">
            </el-table-column>

                      <el-table-column
                    prop="liaisonMan"
                    header-align="center"
                    align="center"
                    label="联系人">
            </el-table-column>
                      <el-table-column
                    prop="liaisonPhone"
                    header-align="center"
                    align="center"
                    label="联系电话">
            </el-table-column>
            <el-table-column
              prop="executionTime"
              header-align="center"
              align="center"
              label="印章日期">
            </el-table-column>


                    <el-table-column
                      fixed="right"
                  header-align="center"
                  align="center"
                  label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.process_decideperform_edit" type="text" size="small" icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改</el-button>
              <el-button v-if="permissions.process_decideperform_del" type="text" size="small" icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除</el-button>
              <el-button v-if="permissions.process_decideperform_wordpdf" type="text" size="small"
                         icon="el-icon-download" @click="download(scope.row.id)">下载
              </el-button>
              <el-button v-if="permissions.process_decideperform_wordpdf" type="text" size="small"
                         icon="el-icon-view" @click="viewPdf(scope.row.id)">预览
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
                @size-change="sizeChangeHandle"
                @current-change="currentChangeHandle"
                :current-page="pageIndex"
                :page-sizes="[10, 20, 50, 100]"
                :page-size="pageSize"
                :total="totalPage"
                background
                layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj,createWord} from '@/api/process/decideperform'
  import {wordToPdf, download, viewPdf} from '@/api/process/wordcommon'
  import TableForm from './decideperform-form'
  import {mapGetters} from 'vuex'
  export default {
    data () {
      return {
        dataForm: {
          key: ''
        },
        dataList: [],
        pageIndex: 1,
        pageSize: 10,
        totalPage: 0,
        dataListLoading: false,
        addOrUpdateVisible: false
      }
    },
    components: {
      TableForm
    },
    created () {
      this.getDataList()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getDataList () {
        this.dataListLoading = true
        fetchList(Object.assign({
          current: this.pageIndex,
          size: this.pageSize
        })).then(response => {
          this.dataList = response.data.data.records
          this.totalPage = response.data.data.total
        })
        this.dataListLoading = false
      },
      // 每页数
      sizeChangeHandle (val) {
        this.pageSize = val
        this.pageIndex = 1
        this.getDataList()
      },
      // 当前页
      currentChangeHandle (val) {
        this.pageIndex = val
        this.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle (id) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(id)
        })
      },

      //下载word
      download(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            download(res.data.data)
          }
        })
      },

      //预览pdf
      viewPdf(id) {
        createWord(id).then(res => {
          if (res.data.code == 0) {
            wordToPdf(res.data.data).then(res1 => {
              viewPdf(res1.data.data)
            })
          }
        })
      },

      // 删除
      deleteHandle (id) {
        this.$confirm('是否确认删除ID为' + id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getDataList()
        })
      }
    }
  }
</script>
